@@ -2,7 +2,7 @@
 # Configuration file for using the xslt library
 #
 XSLT_LIBDIR="-L/usr/lib"
-XSLT_LIBS="-lxslt -lxml2 -licui18n -licuuc -licudata -lz -llzma -liconv -lm  "
+XSLT_LIBS="-lxslt -lxml2 "
 XSLT_PRIVATE_LIBS=""
 XSLT_INCLUDEDIR="-I/usr/include"
-MODULE_VERSION="xslt-1.1.34"
+MODULE_VERSION="xslt-1.1.42"
